************************************************
What is TARDIS actually doing (Physics section)?
************************************************

This section describes some of the Physics going on in TARDIS and will be
gradually expanded

.. toctree::
    :maxdepth: 1

    physical_quantities
    montecarlo
    plasma
